/*
	SambaScanner - A tool to scan Samba networks for files.
	Copyright (C) 2005-2007 Johannes Bauer
	
	This file is part of SambaScanner.

    SambaScanner is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; this program is ONLY licensed under
	version 2 of the License, later versions are explicitly excluded.

    SambaScanner is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with SambaScanner; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

	Johannes Bauer
	Mussinanstr. 140
	92318 Neumarkt/Opf.
	JohannesBauer@gmx.de
*/

#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

#include "sambascanner.h"
#include "Mutex.h"
#include "String.h"
#include "Parser.h"

#define BUFSIZE			1024

int Parse_Groupinfo(char *Filename, char *Workgroup) {
	FILE *f;
	char Buffer[BUFSIZE];

	f = fopen(Filename, "r");
	if (!f) {
		fprintf(stderr, "Error parsing master browser file '%s': %s\n", Filename, strerror(errno));
		return 1;
	}

	while (fgets(Buffer, BUFSIZE, f) != NULL) {
		if (strlen(Buffer) >= 32) {
			if (!strncmp(Buffer + 17, "<00> - <GROUP>", 14)) {
				Buffer[16] = 0;
				Remove_Trailing_Spaces(Buffer);
				strncpy(Workgroup, Buffer + 1, 255);
				break;
			}
		}
	}

	fclose(f);
	return 0;
}

int Parse_Masterbrowser(char *Filename, StringList *Hostlist) {
	FILE *f;
	char Buffer[BUFSIZE];
	
	f = fopen(Filename, "r");
	if (!f) {
		fprintf(stderr, "Error parsing master browser file '%s': %s\n", Filename, strerror(errno));
		return 1;
	}

	while (fgets(Buffer, BUFSIZE, f) != NULL) {
		if (strlen(Buffer) >= 32) {
			if (strncmp(Buffer + 17, "<00> -        ", 14) == 0) {
				Buffer[16] = 0;
				Remove_Trailing_Spaces(Buffer);
				String_Lowercase(Buffer + 1);
				Add_String_Unique_Atomic(Hostlist, Buffer + 1);
			}
		}
	}

	fclose(f);
	return 0;
}

int Parse_Hostinfo(char *Hostname, char *Filename, StringList *Hostlist, StringList *Sharelist) {
	FILE *f;
	char Buffer[BUFSIZE];
	char Buffer2[BUFSIZE];
	char *String;
	
	f = fopen(Filename, "r");
	if (!f) {
		fprintf(stderr, "Error parsing host info file '%s': %s\n", Filename, strerror(errno));
		return 1;
	}

	while (fgets(Buffer, BUFSIZE, f) != NULL) {
		String = strtok(Buffer, "|");
		if (String!=NULL) {
			if (!strcmp(String, "Server")) {
				String = strtok(NULL, "|");
				if (String) {
					String_Lowercase(String);
					Add_String_Unique_Atomic(Hostlist, String);
				}
			}
			if (!strcmp(String, "Disk")) {
				String = strtok(NULL, "|");
				if (String) {
					snprintf(Buffer2, BUFSIZE, "//%s/%s", Hostname, String);
					Add_String_Unique_Atomic(Sharelist, Buffer2);
				}
			}
		}
	}

	fclose(f);
	return 0;
}

int Parse_IP_Address_Info(char *Filename, StringList *Hostlist) {
	FILE *f;
	char Buffer[BUFSIZE];

	f = fopen(Filename, "r");
	if (!f) {
		message(1, "Error parsing IP address info file '%s': %s\n", Filename, strerror(errno));
		return 1;
	}

	while (fgets(Buffer, BUFSIZE, f) != NULL) {
		if (strlen(Buffer) >= 25) {
			if (!strncmp(Buffer + 17, "<00> -  ", 8)) {
				Buffer[17] = 0;
				Remove_Trailing_Spaces(Buffer);
				String_Lowercase(Buffer + 1);
				Add_String_Unique_Atomic(Hostlist, Buffer + 1);
			}
		}
	}

	fclose(f);
	return 0;
}

